pub struct ScopePolicyRegistry { /* private fields */ }Expand description
Scope policy registry that can be instantiated for isolated testing.
For most use cases, use the global functions (register_scope_policy, etc.)
which operate on a shared global registry.
Implementations